@@ -3,7 +3,7 @@
 #
 
 
-  
+
 sendplot <- function(mat, plot.calls, x,y, mai.mat=NA, mai.prc=FALSE,
                      xlim=NA, ylim=NA,z=NA,
                      z.value="value",type="scatterplot", plt.extras = NA,
@@ -21,60 +21,60 @@ sendplot <- function(mat, plot.calls, x,y, mai.mat=NA, mai.prc=FALSE,
 
 
    cat("NOTE:  sendplot function is deprecated\n      Please see makeSplot \n\n\n")
- 
-  
-  
-  # figure out operating system 
+
+
+
+  # figure out operating system
   platform = .Platform$OS.type
   # if source.plot is not specified default to appropriate file
-  #  source plot can only by png or ps 
+  #  source plot can only by png or ps
   if(is.na(source.plot) | !(source.plot=="ps" | source.plot=="png")){
     if(platform == "unix") source.plot = "ps"
-    if(platform == "windows" | platform == "mac") source.plot = "png"   
+    if(platform == "windows" | platform == "mac") source.plot = "png"
   }
-    
+
   # set up file names
   fname.ps=paste(fname.root,".ps",sep="")
   fname.png=paste(fname.root,".png",sep="")
   fname.tif=paste(fname.root,".tif",sep="")
-  
+
   fname.Dot.ps=paste(fname.root,"Dot.ps",sep="")
   fname.Dot.png=paste(fname.root,"Dot.png",sep="")
   fname.Dot.tif=paste(fname.root,"Dot.tif",sep="")
-  
+
 
 
 
 
   if(!automap){
-  
+
     # begin png file if flagged
     if(source.plot=="png"){
       wi = strsplit(resize, "x")[[1]][1]
       hi = strsplit(resize, "x")[[1]][2]
-      png(filename=fname.png, width=as.real(wi), height=as.real(hi))
+      png(filename=fname.png, width=as.double(wi), height=as.double(hi))
     }
     # begin postscript file if flagged
     if(source.plot=="ps"){
       postscript(file=paste(dir,fname.ps,sep=""),paper=ps.paper,width=ps.width,height=ps.height,horizontal=FALSE)
     }
-  
+
     # initiate layout
     # lcm(c())
 
     if(max(as.vector(mat),na.rm=TRUE)>1) nf = layout(mat, respect=TRUE)
     if(mai.prc) mai.def=par("mai")
-  
+
     # loop over plot calls to place plots in order or 1:n in layout
     for(i in 1:length(plot.calls)){
-    
+
       if(length(mai.mat)>1){
         # set up plot margins
         cat("setting margins \n")
         if(!mai.prc) par(mai=mai.mat[i,])
-        if(mai.prc)  par(mai=mai.mat[i,]*mai.def)            
+        if(mai.prc)  par(mai=mai.mat[i,]*mai.def)
       }
-    
+
       # add xlim and ylim arguments to first plot if plot is scatterplot
       if(i==1 & type!="image"){
         plt.call = plot.calls[i]
@@ -85,13 +85,13 @@ sendplot <- function(mat, plot.calls, x,y, mai.mat=NA, mai.prc=FALSE,
         }else{
           if(type!="image"){
             if(!exists("xlim")) xlim = range(x, na.rm=TRUE)
-            if(!exists("ylim")) ylim = range(y, na.rm=TRUE) 
-            ln = nchar(plt.call) 
+            if(!exists("ylim")) ylim = range(y, na.rm=TRUE)
+            ln = nchar(plt.call)
             plot.calls[i] = paste(substr(plt.call,1,ln-1),", xlim=c(",xlim[1],",",xlim[2],"), ylim=c(",ylim[1],",",ylim[2],"))",sep="")
           }
         }
       }# end if i == 1
-    
+
       # plot
       # evaluate plot call
       plt = eval.js(plot.calls[i])
@@ -108,7 +108,7 @@ sendplot <- function(mat, plot.calls, x,y, mai.mat=NA, mai.prc=FALSE,
         ny=length(y)
         ymin=y[1]-(y[2]-y[1])/2
         ymax=y[ny]+(y[ny]-y[ny-1])/2
-      
+
         # changed to blue since default image colors are red and orange
         points(xmin,ymax, pch=22,bg="blue",col="blue", cex=3)
         points(xmax,ymin, pch=22,bg="blue",col="blue", cex=3)
@@ -128,9 +128,9 @@ sendplot <- function(mat, plot.calls, x,y, mai.mat=NA, mai.prc=FALSE,
       for(sp in 1:sub.np){
         if(!is.na(plt.extras[[i]][[sp]]))
           eval.js(plt.extras[[i]][[sp]])
-      }     
+      }
     }# end for loop over plot calls
-  
+
     # turn off postscript device
     dev.off()
 
@@ -138,44 +138,44 @@ sendplot <- function(mat, plot.calls, x,y, mai.mat=NA, mai.prc=FALSE,
     if(source.plot=="ps" & platform=="unix"){
       system(paste("convert ",dir,fname.ps," -size 800x1100 -resize ",resize," ",dir,fname.png,sep=""))
     }
-    
+
     # if flagged system call to open paint
     # if first time running program to find upper left and lower right corners of main plot
     if(paint){
-      if(is.na(img.prog)){      
+      if(is.na(img.prog)){
         if(platform=="unix") system(paste("kolourpaint ", dir,fname.png," &", sep=""))
         if(platform=="windows") system(paste("mspaint ", dir,fname.png," &", sep=""))
         if(platform=="mac") cat("automatic open is not supported in this version for MAC OS \n")
       }else{
         # some other program has been specified to open png image
         system(paste(img.prog, " ", dir, fname.png, " &", sep=""))
-      }    
+      }
     }
-    
+
   } # end if !automap
 
 
 
   if(automap){
-  
+
   bound.pt = FALSE
-  
+
   #
-  # first make file with additional markers at bounding box 
+  # first make file with additional markers at bounding box
   #
 
-  
+
   # begin png file if flagged
   if(source.plot=="png"){
     wi = strsplit(resize, "x")[[1]][1]
     hi = strsplit(resize, "x")[[1]][2]
-    png(filename=fname.Dot.png, width=as.real(wi), height=as.real(hi))
+    png(filename=fname.Dot.png, width=as.double(wi), height=as.double(hi))
   }
   # begin postscript file if flagged
   if(source.plot=="ps"){
     postscript(file=paste(dir,fname.Dot.ps,sep=""),paper=ps.paper,width=ps.width,height=ps.height,horizontal=FALSE)
   }
-  
+
   # initiate layout
   # lcm(c())
 
@@ -185,18 +185,18 @@ sendplot <- function(mat, plot.calls, x,y, mai.mat=NA, mai.prc=FALSE,
   if(mai.prc) mai.def=par("mai")
 
   orig.plots = plot.calls
-  
+
   # loop over plot calls to place plots in order or 1:n in layout
   for(i in 1:length(plot.calls)){
 
-    
+
     if(length(mai.mat)>1){
       # set up plot margins
       cat("setting margins \n")
       if(!mai.prc) par(mai=mai.mat[i,])
-      if(mai.prc)  par(mai=mai.mat[i,]*mai.def)            
+      if(mai.prc)  par(mai=mai.mat[i,]*mai.def)
     }
-    
+
     # add xlim and ylim arguments to first plot if plot is scatterplot
     if(i==1 & type!="image"){
       plt.call = plot.calls[i]
@@ -207,13 +207,13 @@ sendplot <- function(mat, plot.calls, x,y, mai.mat=NA, mai.prc=FALSE,
       }else{
         if(type!="image"){
           if(!exists("xlim")) xlim = range(x, na.rm=TRUE)
-          if(!exists("ylim")) ylim = range(y, na.rm=TRUE) 
-          ln = nchar(plt.call) 
+          if(!exists("ylim")) ylim = range(y, na.rm=TRUE)
+          ln = nchar(plt.call)
           plot.calls[i] = paste(substr(plt.call,1,ln-1),", xlim=c(",xlim[1],",",xlim[2],"), ylim=c(",ylim[1],",",ylim[2],"))",sep="")
         }
       }
     }# end if i == 1
-    
+
     # plot
     # evaluate plot call
     plt = eval.js(plot.calls[i])
@@ -230,7 +230,7 @@ sendplot <- function(mat, plot.calls, x,y, mai.mat=NA, mai.prc=FALSE,
       ny=length(y)
       ymin=y[1]-(y[2]-y[1])/2
       ymax=y[ny]+(y[ny]-y[ny-1])/2
-      
+
       # changed to blue since default image colors are red and orange
       points(xmin,ymax, pch=21,bg="blue",col="blue", cex=3)
       points(xmax,ymin, pch=21,bg="blue",col="blue", cex=3)
@@ -250,30 +250,30 @@ sendplot <- function(mat, plot.calls, x,y, mai.mat=NA, mai.prc=FALSE,
     for(sp in 1:sub.np){
       if(!is.na(plt.extras[[i]][[sp]]))
         eval.js(plt.extras[[i]][[sp]])
-    }     
+    }
   }# end for loop over plot calls
-  
+
   # turn off postscript device
   dev.off()
-  
+
   # convert ps to png if ps was made and on unix OS
   if(source.plot=="ps" & platform=="unix"){
     system(paste("convert ",dir,fname.Dot.ps," -size 800x1100 -resize ",resize," ",dir,fname.Dot.png,sep=""))
     system(paste("convert ",dir,fname.Dot.png, " ", dir,fname.Dot.tif,sep=""))
   }
-    
+
   # if flagged system call to open paint
   # if first time running program to find upper left and lower right corners of main plot
   if(paint){
-    
-    if(is.na(img.prog)){      
+
+    if(is.na(img.prog)){
       if(platform=="unix") system(paste("kolourpaint ", dir,fname.Dot.png," &", sep=""))
       if(platform=="windows") system(paste("mspaint ", dir,fname.Dot.png," &", sep=""))
       if(platform=="mac") cat("automatic open is not supported in this version for MAC OS \n")
     }else{
       # some other program has been specified to open png image
       system(paste(img.prog, " ", dir, fname.Dot.png, " &", sep=""))
-    }    
+    }
 
   }
 
@@ -282,19 +282,19 @@ sendplot <- function(mat, plot.calls, x,y, mai.mat=NA, mai.prc=FALSE,
   #
 
   # reset plot calls (without xlim,ylim)
-  plot.calls = orig.plots 
-  
+  plot.calls = orig.plots
+
   # begin png file if flagged
   if(source.plot=="png"){
     wi = strsplit(resize, "x")[[1]][1]
     hi = strsplit(resize, "x")[[1]][2]
-    png(filename=fname.png, width=as.real(wi), height=as.real(hi))
+    png(filename=fname.png, width=as.double(wi), height=as.double(hi))
   }
   # begin postscript file if flagged
   if(source.plot=="ps"){
     postscript(file=paste(dir,fname.ps,sep=""),paper=ps.paper,width=ps.width,height=ps.height,horizontal=FALSE)
   }
-  
+
   # initiate layout
   # lcm(c())
 
@@ -302,18 +302,18 @@ sendplot <- function(mat, plot.calls, x,y, mai.mat=NA, mai.prc=FALSE,
   if(max(as.vector(mat),na.rm=TRUE)>1) nf = layout(mat, respect=TRUE)
 
   if(mai.prc) mai.def=par("mai")
-  
+
   # loop over plot calls to place plots in order or 1:n in layout
   for(i in 1:length(plot.calls)){
 
-    
+
     if(length(mai.mat)>1){
       # set up plot margins
       cat("setting margins \n")
       if(!mai.prc) par(mai=mai.mat[i,])
-      if(mai.prc)  par(mai=mai.mat[i,]*mai.def)            
+      if(mai.prc)  par(mai=mai.mat[i,]*mai.def)
     }
-    
+
     # add xlim and ylim arguments to first plot if plot is scatterplot
     if(i==1 & type!="image"){
       plt.call = plot.calls[i]
@@ -324,18 +324,18 @@ sendplot <- function(mat, plot.calls, x,y, mai.mat=NA, mai.prc=FALSE,
       }else{
         if(type!="image"){
           if(!exists("xlim")) xlim = range(x, na.rm=TRUE)
-          if(!exists("ylim")) ylim = range(y, na.rm=TRUE) 
-          ln = nchar(plt.call) 
+          if(!exists("ylim")) ylim = range(y, na.rm=TRUE)
+          ln = nchar(plt.call)
           plot.calls[i] = paste(substr(plt.call,1,ln-1),", xlim=c(",xlim[1],",",xlim[2],"), ylim=c(",ylim[1],",",ylim[2],"))",sep="")
         }
       }
     }# end if i == 1
-    
+
     # plot
     # evaluate plot call
     plt = eval.js(plot.calls[i])
-   
- 
+
+
     # evaluate other plotting call if necessary
     # if plt.extras is NA no plotting for all plots
     if(length(plt.extras)==1){
@@ -350,50 +350,50 @@ sendplot <- function(mat, plot.calls, x,y, mai.mat=NA, mai.prc=FALSE,
     for(sp in 1:sub.np){
       if(!is.na(plt.extras[[i]][[sp]]))
         eval.js(plt.extras[[i]][[sp]])
-    }     
+    }
   }# end for loop over plot calls
-  
+
   # turn off postscript device
   dev.off()
-  
+
   # convert ps to png if ps was made and on unix OS
   if(source.plot=="ps" & platform=="unix"){
     system(paste("convert ",dir,fname.ps," -size 800x1100 -resize ",resize," ",dir,fname.png,sep=""))
     system(paste("convert ",dir,fname.png, " ", dir,fname.tif,sep=""))
-  }   
-         
-    
+  }
+
+
   # if flagged system call to open paint
   # if first time running program to find upper left and lower right corners of main plot
   if(paint){
-    
-    if(is.na(img.prog)){      
+
+    if(is.na(img.prog)){
       if(platform=="unix") system(paste("kolourpaint ", dir,fname.png," &", sep=""))
       if(platform=="windows") system(paste("mspaint ", dir,fname.png," &", sep=""))
       if(platform=="mac") cat("automatic open is not supported in this version for MAC OS \n")
     }else{
       # some other program has been specified to open png image
       system(paste(img.prog, " ", dir, fname.png, " &", sep=""))
-    }    
+    }
   }
-   
+
 
 
   #
   # Now begin automatic detection of points if tif files are found
-  #  
+  #
 
   d = dir(dir)
   dot.loc = which(d == fname.Dot.tif)
   fin.loc = which(d == fname.tif)
 
   # needs tif files for rtiff
-  
- 
+
+
   if( (length(dot.loc) != 0) | (length(fin.loc) != 0) ){
 
     require("rtiff")
-    # reads tiff files 
+    # reads tiff files
     tif.dot = readTiff(paste(dir, fname.Dot.tif,sep=""))
     tif.fin = readTiff(paste(dir, fname.tif,sep=""))
 
@@ -407,7 +407,7 @@ sendplot <- function(mat, plot.calls, x,y, mai.mat=NA, mai.prc=FALSE,
     # determin column locations of where tifs differ
     row.count = rowSums(temp, na.rm=TRUE)
     col.loc = which(row.count>0)
-    
+
     # store largest break between locations to seperate lower and upper bound
     len = length((col.loc[1]):(col.loc[2]))
     brk = 1
@@ -427,7 +427,7 @@ sendplot <- function(mat, plot.calls, x,y, mai.mat=NA, mai.prc=FALSE,
     col.reg.2 = (col.loc[brk]):(col.loc[(length(col.loc))])
 
     #
-    # currently can find locations by median or mode 
+    # currently can find locations by median or mode
     #
 
     # if find by median
@@ -435,49 +435,49 @@ sendplot <- function(mat, plot.calls, x,y, mai.mat=NA, mai.prc=FALSE,
       #
       # find upper bound
       #
-      
+
       #dx1 = floor(length(col.reg.1)/2)
       #dx2 = floor(length(col.reg.2)/2)
       #r1.col = col.reg.1[dx1]
 
-      # column loc is median 
+      # column loc is median
       r1.col = floor(median(col.reg.1))
       # row location is length of different in determine column
       r1.row = which(temp[r1.col,]>0)[1]
-      add.r = floor((row.count[r1.col])/2) 
+      add.r = floor((row.count[r1.col])/2)
       up.left.row = r1.row + add.r
       # add additional to compensate for row
       add.c = floor((length(which(row.count[col.reg.1] == row.count[r1.col])))/2)
-      up.left.col = r1.col + add.c 
-  
+      up.left.col = r1.col + add.c
+
       #
       # find lower bound
       #
-      
+
       #r2.col = col.reg.2[dx2]
-      
+
       # column loc is median
       r2.col = floor(median(col.reg.2))
       # row location is length of different in determine column
       r2.row = which(temp[r2.col,]>0)[1]
-      add2.r = floor((row.count[r2.col])/2) 
+      add2.r = floor((row.count[r2.col])/2)
       low.right.row = r2.row + add2.r
       # add additional to compensate for row
       add2.c = floor((length(which(row.count[col.reg.2] == row.count[r2.col])))/2)
-      low.right.col = r2.col + add2.c 
+      low.right.col = r2.col + add2.c
 
     } # end if median
 
-    
+
     # if find by mode (default)
     if(automap.method == "mode"){
-  
-      # 
+
+      #
       # find upper bound
       #
 
       # finds which length repeats most often
-      vec = row.count[col.reg.1] 
+      vec = row.count[col.reg.1]
       u = unique(vec)
       fr = u[1]
       len = length(which(vec == fr))
@@ -486,20 +486,20 @@ sendplot <- function(mat, plot.calls, x,y, mai.mat=NA, mai.prc=FALSE,
         if(c > len){
           fr = i
           len = c
-        }    
+        }
       }
 
-      # column is which repeats most often 
+      # column is which repeats most often
       r1.col = which(row.count == fr)[1]
       # row location is length of different in determine column
       r1.row = which(temp[r1.col,]>0)[1]
-      add.r = floor(fr/2) 
+      add.r = floor(fr/2)
       up.left.row = r1.row + add.r
       # add additional to compensate for row
       add.c = floor((len/2))
-      up.left.col = r1.col + add.c 
+      up.left.col = r1.col + add.c
 
-      # if no row repeats, uses median method      
+      # if no row repeats, uses median method
       if(len == 1){
         #dx1 = floor(length(col.reg.1)/2)
         #r1.col = col.reg.1[dx1]
@@ -508,20 +508,20 @@ sendplot <- function(mat, plot.calls, x,y, mai.mat=NA, mai.prc=FALSE,
         r1.col = floor(median(col.reg.1))
         # row location is length of different in determine column
         r1.row = which(temp[r1.col,]>0)[1]
-        add.r = floor((row.count[r1.col])/2) 
+        add.r = floor((row.count[r1.col])/2)
         up.left.row = r1.row + add.r
         # add additional to compensate for row
         add.c = floor((length(which(row.count[col.reg.1] == row.count[r1.col])))/2)
-        up.left.col = r1.col + add.c 
+        up.left.col = r1.col + add.c
       }
 
-      
+
       #
       # lower bound
       #
-      
+
       # finds which length repeats most often
-      vec2 = row.count[col.reg.2] 
+      vec2 = row.count[col.reg.2]
       u2 = unique(vec2)
       fr2 = u2[1]
       len2 = length(which(vec2 == fr2))
@@ -530,23 +530,23 @@ sendplot <- function(mat, plot.calls, x,y, mai.mat=NA, mai.prc=FALSE,
         if(c2 > len2){
           fr2 = i2
           len2 = c2
-        }    
+        }
       }
-      
-      # column is which repeats most often 
+
+      # column is which repeats most often
       r2.col =  which(row.count == fr2)
       r2.col = r2.col[which(r2.col > (s.reg.1 + length(col.reg.1)))][1]
       # row location is length of different in determine column
       r2.row = which(temp[r2.col,]>0)[1]
-      add2.r = floor(fr2/2) 
+      add2.r = floor(fr2/2)
       low.right.row = r2.row + add2.r
       # add additional to compensate for row
       add2.c = floor((len2/2))
-      low.right.col = r2.col + add2.c 
+      low.right.col = r2.col + add2.c
 
-      # if no row repeats, uses median method  
+      # if no row repeats, uses median method
       if(len2 == 1){
-        
+
         #dx2 = floor(length(col.reg.2)/2)
         #r2.col = col.reg.2[dx2]
 
@@ -554,23 +554,23 @@ sendplot <- function(mat, plot.calls, x,y, mai.mat=NA, mai.prc=FALSE,
         r2.col = floor(median(col.reg.2))
         # row location is length of different in determine column
         r2.row = which(temp[r2.col,]>0)[1]
-        add2.r = floor((row.count[r2.col])/2) 
+        add2.r = floor((row.count[r2.col])/2)
         low.right.row = r2.row + add2.r
         # add additional to compensate for row
         add2.c = floor((length(which(row.count[col.reg.2] == row.count[r2.col])))/2)
-        low.right.col = r2.col + add2.c 
+        low.right.col = r2.col + add2.c
       }
     } # end if mode
-    
 
-  
-    # set bound points 
+
+
+    # set bound points
     up.left=c(up.left.row,up.left.col)
     low.right=c(low.right.row,low.right.col)
 
     cat(paste("The bounding locations are:\n    up.left: ", up.left.row, ", ", up.left.col,"\n
    low.right: ", low.right.row, ", ", low.right.col, "\n"))
-    
+
   }else{ # ends if tif files found
 
     #
@@ -580,7 +580,7 @@ sendplot <- function(mat, plot.calls, x,y, mai.mat=NA, mai.prc=FALSE,
     #     else run manual detection of bounds
     #
 
-    
+
     bound.pt = TRUE
     cat("automatic points only fully functional on unix machines \n")
     cat("one of the required tif files is not found \n")
@@ -592,25 +592,25 @@ sendplot <- function(mat, plot.calls, x,y, mai.mat=NA, mai.prc=FALSE,
     cat("     and run function again \n")
     cat(" OR \n")
     cat("     2. find bounding points manually. See vignette for help \n")
-    
+
   } # ends if tif files not found
 
 } # end automap
 
 
 
-  
+
   # if flagged make interactive html
-  if(!bound.pt){ 
-  
+  if(!bound.pt){
+
     # set up data frame of information
     # information in this data frame will be displayed for points in interactive window
     if(type=="scatterplot"){
-      
+
       # estimate pixil location
       x.new = round(up.left[1] + ((x-xlim[1])/(xlim[2]-xlim[1]))*(low.right[1]-up.left[1]))
       y.new = round(up.left[2] + ((ylim[2]-y)/(ylim[2]-ylim[1]))*(low.right[2]-up.left[2]))
-      
+
       # initiate data frame
       dat = data.frame(
         # pixil locations
@@ -635,11 +635,11 @@ sendplot <- function(mat, plot.calls, x,y, mai.mat=NA, mai.prc=FALSE,
         }
       }
       # if x.lbls is not NA continue
-      if(contx){     
+      if(contx){
         for(i in 1:dim(x.lbls)[2]){
           if(i == 1) z.value = names(x.lbls)[i]
           eval.js(paste("dat$",names(x.lbls)[i], "=as.vector(x.lbls[,i])", sep=""))
-        }      
+        }
       }
       # y specific data
       conty = TRUE
@@ -652,9 +652,9 @@ sendplot <- function(mat, plot.calls, x,y, mai.mat=NA, mai.prc=FALSE,
         conty = FALSE
         cat(paste("Warning: y.lbls does not have correct dimensions \n   number of rows should equal length(y):",length(y), "\n   Continuing with y.lbls = NA", sep=""))
         y.lbls = NA
-      }      
+      }
       # if y.lbls is not NA continue
-      if(conty){     
+      if(conty){
         for(i in 1:dim(y.lbls)[2]){
           if((i == 1) & !contx) z.value = names(y.lbls)[i]
           eval.js(paste("dat$",names(y.lbls)[i], "=as.vector(y.lbls[,i])", sep=""))
@@ -671,17 +671,17 @@ sendplot <- function(mat, plot.calls, x,y, mai.mat=NA, mai.prc=FALSE,
         contxy = FALSE
         cat(paste("Warning: xy.lbls does not have correct dimensions \n   number of rows should equal length(y):",length(y), " or length(x):", length(x), "\n   Continuing with xy.lbls = NA", sep=""))
         xy.lbls = NA
-      }         
+      }
       # if xy.lbls is not NA continue
-      if(contxy){     
+      if(contxy){
         for(i in 1:dim(xy.lbls)[2]){
           if((i == 1) & !contx & !conty) z.value = names(xy.lbls)[i]
           eval.js(paste("dat$",names(xy.lbls)[i], "=as.vector(xy.lbls[,i])", sep=""))
         }
       }
       # if all: x.lbls, y.lbls, and xy.lbls were NA no data to display
-      # set up dummy vector with blanks 
-      if(!contx & !conty & !contxy){  
+      # set up dummy vector with blanks
+      if(!contx & !conty & !contxy){
         eval.js(paste("dat$", z.value, "=rep('',dim(dat)[2])",sep=""))
       }
 
@@ -711,20 +711,20 @@ sendplot <- function(mat, plot.calls, x,y, mai.mat=NA, mai.prc=FALSE,
             # if not NA
             if(is.na(tmp)){
               temp[j] = NA
-            # split multiple links...assumed seperated by a comma  
+            # split multiple links...assumed seperated by a comma
             }else{
               links = strsplit(tmp, split=",")[[1]]
               new.t = " "
               for(l in 1:length(links)){
-                new.t = paste(new.t, paste("<a href=\\'", gsub(links[l], pattern=" ", replacement=""), "\\'> ", paste((names(x.links)[i]),l, sep="."), " </a>", sep=""), sep=",")          
+                new.t = paste(new.t, paste("<a href=\\'", gsub(links[l], pattern=" ", replacement=""), "\\'> ", paste((names(x.links)[i]),l, sep="."), " </a>", sep=""), sep=",")
               }
               new.t = gsub(new.t, pattern=" ,", replacement="")
               temp[j] = new.t
             }
           }
           # put link in correct syntax into character matrix
-          eval.js(paste("dat2$", names(x.links)[i], "=temp", sep=""))    
-        }  
+          eval.js(paste("dat2$", names(x.links)[i], "=temp", sep=""))
+        }
       }
 
       # if y specific hyperlinks
@@ -752,22 +752,22 @@ sendplot <- function(mat, plot.calls, x,y, mai.mat=NA, mai.prc=FALSE,
             # if not NA
             if(is.na(tmp)){
               temp[j] = NA
-            # split multiple links...assumed seperated by a comma 
+            # split multiple links...assumed seperated by a comma
             }else{
               links = strsplit(tmp, split=",")[[1]]
               new.t = " "
               for(l in 1:length(links)){
-                new.t = paste(new.t, paste("<a href=\\'", gsub(links[l], pattern=" ", replacement=""), "\\'> ", paste((names(y.links)[i]),l, sep="."), " </a>", sep=""), sep=",")          
+                new.t = paste(new.t, paste("<a href=\\'", gsub(links[l], pattern=" ", replacement=""), "\\'> ", paste((names(y.links)[i]),l, sep="."), " </a>", sep=""), sep=",")
               }
               new.t = gsub(new.t, pattern=" ,", replacement="")
               temp[j] = new.t
             }
           }
           # put link in correct syntax into character matrix
-          eval.js(paste("dat2$", names(y.links)[i], "=temp", sep=""))    
-        }  
+          eval.js(paste("dat2$", names(y.links)[i], "=temp", sep=""))
+        }
       }
-      
+
       # if xy specific hyperlinks
       cont = TRUE
       xy.links = as.data.frame(xy.links)
@@ -791,26 +791,26 @@ sendplot <- function(mat, plot.calls, x,y, mai.mat=NA, mai.prc=FALSE,
             # if not NA
             if(is.na(tmp)){
               temp[j] = NA
-            # split multiple links...assumed seperated by a comma   
+            # split multiple links...assumed seperated by a comma
             }else{
               links = strsplit(tmp, split=",")[[1]]
               new.t = " "
               for(l in 1:length(links)){
-                new.t = paste(new.t, paste("<a href=\\'", gsub(links[l], pattern=" ", replacement=""), "\\'> ", paste((names(xy.links)[i]),l, sep="."), " </a>", sep=""), sep=",")          
+                new.t = paste(new.t, paste("<a href=\\'", gsub(links[l], pattern=" ", replacement=""), "\\'> ", paste((names(xy.links)[i]),l, sep="."), " </a>", sep=""), sep=",")
               }
               new.t = gsub(new.t, pattern=" ,", replacement="")
               temp[j] = new.t
             }
           }
           # put link in correct syntax into character matrix
-          eval.js(paste("dat2$", names(xy.links)[i], "=temp", sep=""))    
-        }  
+          eval.js(paste("dat2$", names(xy.links)[i], "=temp", sep=""))
+        }
       }
 
 
-  
 
-      # get points as Links information 
+
+      # get points as Links information
       contLinks = TRUE
       # if data frame convert to matrix
       if(class(asLinks) == "data.frame") asLinks = as.matrix(asLinks)
@@ -825,26 +825,26 @@ sendplot <- function(mat, plot.calls, x,y, mai.mat=NA, mai.prc=FALSE,
         cat("Warning: cannot create points as links \n     length must be equal to x or y \n")
         contLinks = FALSE
       }
-    
 
-      
-      
-      
+
+
+
+
     }# end if scatterplot
-    
+
     if(type=="image"){
-      
+
       # calculate width and height of active image
       wdth=low.right[1]-up.left[1]
       hght=low.right[2]-up.left[2]
-      # get min and max x values for image      
+      # get min and max x values for image
       nx=length(x)
       xmin=x[1]-(x[2]-x[1])/2
       xmax=x[nx]+(x[nx]-x[nx-1])/2
       # calculate cuts and center of x values on image
       bndrs=c(xmin,(x[1:(nx-1)]+x[2:nx])/2,xmax)
       cntrs=(bndrs[1:(length(bndrs)-1)]+bndrs[2:length(bndrs)])/2
-      # adjust 
+      # adjust
       unit.int.wdth=cntrs-xmin
       unit.int.wdth=unit.int.wdth/(xmax-xmin)
       # calculate pixil positions
@@ -861,7 +861,7 @@ sendplot <- function(mat, plot.calls, x,y, mai.mat=NA, mai.prc=FALSE,
       unit.int.hght=unit.int.hght/(ymax-ymin)
       # calculate pixil positions
       y.image= round((1-unit.int.hght)*hght+up.left[2])
-          
+
       # initiate data frame of info
       dat = data.frame(
         # pixil locations
@@ -885,11 +885,11 @@ sendplot <- function(mat, plot.calls, x,y, mai.mat=NA, mai.prc=FALSE,
         if(dim(x.lbls)[1] != length(x)){
           cont = FALSE
           cat(paste("Warning: x.lbls does not have correct dimensions \n   number of rows should equal length(x):",length(x), "\n   Continuing with x.lbls = NA", sep=""))
-          x.lbls = NA      
-        }         
-      }       
+          x.lbls = NA
+        }
+      }
       # if x.lbls is not NA continue
-      if(cont){     
+      if(cont){
         for(i in 1:dim(x.lbls)[2]){
           eval.js(paste("dat$",names(x.lbls)[i], "=as.vector(mapply(rep,x=x.lbls[,i], MoreArgs=list(times=length(y.image))))", sep=""))
         }
@@ -905,11 +905,11 @@ sendplot <- function(mat, plot.calls, x,y, mai.mat=NA, mai.prc=FALSE,
         if(dim(y.lbls)[1] != length(y)){
           cont = FALSE
           cat(paste("Warning: y.lbls does not have correct dimensions \n   number of rows should equal length(y):",length(y), "\n   Continuing with y.lbls = NA", sep=""))
-          y.lbls = NA      
-        }         
-      }    
+          y.lbls = NA
+        }
+      }
       # if y.lbls is not NA continue
-      if(cont){     
+      if(cont){
         for(i in 1:dim(y.lbls)[2]){
           eval.js(paste("dat$",names(y.lbls)[i], "=rep(y.lbls[,i],length(x.image))", sep=""))
         }
@@ -920,14 +920,14 @@ sendplot <- function(mat, plot.calls, x,y, mai.mat=NA, mai.prc=FALSE,
       if(cont){
         for(i in 1:length(xy.lbls)){
           # check dimension
-          if((dim(xy.lbls[[i]])[2] == length(x)) & (dim(xy.lbls[[i]])[1] == length(y))){                  
+          if((dim(xy.lbls[[i]])[2] == length(x)) & (dim(xy.lbls[[i]])[1] == length(y))){
             eval.js(paste("dat$",names(xy.lbls)[i],"=as.vector(xy.lbls[[i]])", sep=""))
           }else{
-            cat(paste("Warning: at least one of the xy.lbls matricies are not of the correct dimension. \n    All should be of the dimension ",length(x), " by ", length(y), "\n", sep="")) 
-          }                  
+            cat(paste("Warning: at least one of the xy.lbls matricies are not of the correct dimension. \n    All should be of the dimension ",length(x), " by ", length(y), "\n", sep=""))
+          }
         }
       }
-      
+
 
       # x specific hyperlinks
       cont = TRUE
@@ -935,19 +935,19 @@ sendplot <- function(mat, plot.calls, x,y, mai.mat=NA, mai.prc=FALSE,
       if( (dim(x.links)[1]==1) & (dim(x.links)[2]==1)){
         if(is.na(x.links[1,1])) cont = FALSE
       }
-    
+
       # dimension check
       if(cont){
         if(dim(x.links)[1] != length(x)){
           cont = FALSE
           cat(paste("Warning: x.links does not have correct dimensions \n   number of rows should equal length(x):",length(x), "\n   Continuing with x.links = NA", sep=""))
-          x.links = NA      
-        }         
+          x.links = NA
+        }
       }
       # if x.links is not NA
       if(cont){
         # for each column get links
-        for(i in 1:dim(x.links)[2]){           
+        for(i in 1:dim(x.links)[2]){
           eval.js("temp=as.vector(mapply(rep,x=x.links[,i], MoreArgs=list(times=length(y.image))))")
           # for each points link
           for(j in 1:length(temp)){
@@ -960,16 +960,16 @@ sendplot <- function(mat, plot.calls, x,y, mai.mat=NA, mai.prc=FALSE,
               links = strsplit(tmp, split=",")[[1]]
               new.t = " "
               for(l in 1:length(links)){
-                new.t = paste(new.t, paste("<a href=\\'", gsub(links[l], pattern=" ", replacement=""), "\\'> ", paste((names(x.links)[i]),l, sep="."), " </a>", sep=""), sep=",")          
+                new.t = paste(new.t, paste("<a href=\\'", gsub(links[l], pattern=" ", replacement=""), "\\'> ", paste((names(x.links)[i]),l, sep="."), " </a>", sep=""), sep=",")
               }
               new.t = gsub(new.t, pattern=" ,", replacement="")
               temp[j] = new.t
             }
           }
-          # put correctly syntaxed link in matrix 
-          eval.js(paste("dat2$", names(x.links)[i], "=temp", sep=""))    
-        }  
-      }      
+          # put correctly syntaxed link in matrix
+          eval.js(paste("dat2$", names(x.links)[i], "=temp", sep=""))
+        }
+      }
       # y specific hyperlinks
       cont = TRUE
       y.links = as.data.frame(y.links)
@@ -981,8 +981,8 @@ sendplot <- function(mat, plot.calls, x,y, mai.mat=NA, mai.prc=FALSE,
         if(dim(y.links)[1] != length(y)){
           cont = FALSE
           cat(paste("Warning: y.links does not have correct dimensions \n   number of rows should equal length(y):",length(y), "\n   Continuing with y.links = NA", sep=""))
-          y.links = NA      
-        }         
+          y.links = NA
+        }
       }
       # if y.links is not NA
       if(cont){
@@ -1000,15 +1000,15 @@ sendplot <- function(mat, plot.calls, x,y, mai.mat=NA, mai.prc=FALSE,
               links = strsplit(tmp, split=",")[[1]]
               new.t = " "
               for(l in 1:length(links)){
-                new.t = paste(new.t, paste("<a href=\\'", gsub(links[l], pattern=" ", replacement=""), "\\'> ", paste((names(y.links)[i]),l, sep="."), " </a>", sep=""), sep=",")          
+                new.t = paste(new.t, paste("<a href=\\'", gsub(links[l], pattern=" ", replacement=""), "\\'> ", paste((names(y.links)[i]),l, sep="."), " </a>", sep=""), sep=",")
               }
               new.t = gsub(new.t, pattern=" ,", replacement="")
               temp[j] = new.t
             }
           }
-          # put correctly syntaxed link in matrix 
-          eval.js(paste("dat2$", names(y.links)[i], "=temp", sep=""))    
-        }  
+          # put correctly syntaxed link in matrix
+          eval.js(paste("dat2$", names(y.links)[i], "=temp", sep=""))
+        }
       }
 
       # xy specific hyperlinks
@@ -1028,26 +1028,26 @@ sendplot <- function(mat, plot.calls, x,y, mai.mat=NA, mai.prc=FALSE,
               # if not NA
               if(is.na(tmp)){
                 temp[j] = NA
-              # split multiple links...assumed seperated by a comma  
+              # split multiple links...assumed seperated by a comma
               }else{
                 links = strsplit(tmp, split=",")[[1]]
                 new.t = " "
                 for(l in 1:length(links)){
-                  new.t = paste(new.t, paste("<a href=\\'", gsub(links[l], pattern=" ", replacement=""), "\\'> ", paste((names(xy.links)[i]),l, sep="."), " </a>", sep=""), sep=",")          
+                  new.t = paste(new.t, paste("<a href=\\'", gsub(links[l], pattern=" ", replacement=""), "\\'> ", paste((names(xy.links)[i]),l, sep="."), " </a>", sep=""), sep=",")
                 }
                 new.t = gsub(new.t, pattern=" ,", replacement="")
                 temp[j] = new.t
               }
             }
-            # put correctly syntaxed link in matrix 
-            eval.js(paste("dat2$", names(xy.links)[i], "=temp", sep=""))    
+            # put correctly syntaxed link in matrix
+            eval.js(paste("dat2$", names(xy.links)[i], "=temp", sep=""))
           }else{
-            cat(paste("Warning: at least one of the xy.links matricies are not of the correct dimension. \n    All should be of the dimension ",length(x), " by ", length(y), "\n", sep="")) 
-          }          
-        }        
-      }      
-      
-      # get points as Links information 
+            cat(paste("Warning: at least one of the xy.links matricies are not of the correct dimension. \n    All should be of the dimension ",length(x), " by ", length(y), "\n", sep=""))
+          }
+        }
+      }
+
+      # get points as Links information
       contLinks = TRUE
       # if data frame convert to matrix
       if(class(asLinks) == "data.frame") asLinks = as.matrix(asLinks)
@@ -1064,17 +1064,17 @@ sendplot <- function(mat, plot.calls, x,y, mai.mat=NA, mai.prc=FALSE,
         cat("Warning: cannot create points as links \n     length must be equal to x or y or dimensions equal to x*y \n")
         contLinks = FALSE
       }
-          
+
     }#end if image
 
     if(header!="v1" &  header!="v2" ) header="v2"
-    
+
     # mapfile header info
     if(header=="v2") data(v2.header)
     if(header=="v1") data(v1.header)
-    
+
     sp.header=sp.header
-    
+
     # update dat into character array to make writing more efficient
     cdat=array(" ",dim=dim(dat))
     ndat=rep(" ",dim(dat)[2])
@@ -1082,7 +1082,7 @@ sendplot <- function(mat, plot.calls, x,y, mai.mat=NA, mai.prc=FALSE,
       cdat[,j]=as.character(dat[,j])
       ndat[j]=names(dat)[j]
     }
-    
+
     if(header == "v1"){
       cat("Note: hyperlinks only work with header=v2 \n")
     }else{
@@ -1103,38 +1103,38 @@ sendplot <- function(mat, plot.calls, x,y, mai.mat=NA, mai.prc=FALSE,
     # begin html file
     sink(paste(dir,fname.root,".html",sep=""))
 
-    
+
     # add header information
     for(i in 1:length(sp.header)) cat(sp.header[i],fill=TRUE)
-    
+
     # add data point info
     for(i in 1:(dim(dat)[1])){
-      
+
        if(header=="v1"){
-          
+
           ctmp=paste("<area shape=\"circle\" coords=\"",cdat[i,1],",",cdat[i,2],
             ",",spot.radius,"\" onmouseover=\"setData(\'",z.value,"&nbsp;&nbsp;:&nbsp;",
             cdat[i,3],sep="")
-          
+
           if(dim(dat)[2]>3){
             for(j in 4:(dim(dat)[2])){
               ctmp = paste(ctmp, "<br> ",ndat[j],"&amp;nbsp;&amp;nbsp;:&amp;nbsp;",
                 cdat[i,j],sep="")
             }
           }
-          ctmp = paste(ctmp, "\')\" onMouseOut=\"clearData();\" />",sep="")          
-          
+          ctmp = paste(ctmp, "\')\" onMouseOut=\"clearData();\" />",sep="")
+
       }# end if header==v1
 
-      
+
       if(header=="v2"){
-        
+
         ctmp=paste("<area shape=\"circle\" coords=\"",cdat[i,1],",",cdat[i,2],
           ",",spot.radius,"\" onmouseover=\"Tip(\'",z.value,"&nbsp;&nbsp;:&nbsp;",
           cdat[i,3],sep="")
 
         if(dim(cdat)[2]>3){
-    
+
           if(dim(dat)[2]>3){
             for(j in 4:(links.st-1)){
               ctmp = paste(ctmp, "<br> ",ndat[j],"&amp;nbsp;&amp;nbsp;:&amp;nbsp;",
@@ -1148,8 +1148,8 @@ sendplot <- function(mat, plot.calls, x,y, mai.mat=NA, mai.prc=FALSE,
                 linkFlag = TRUE
                 ctmp = paste(ctmp, "<br> ",ndat[j],":", cdat[i,j],sep="")
               }
-            }         
-          }  
+            }
+          }
         }else{
           linkFlag = FALSE
         }
@@ -1161,17 +1161,17 @@ sendplot <- function(mat, plot.calls, x,y, mai.mat=NA, mai.prc=FALSE,
             ctmp = paste(ctmp, " href=\" ", link, "\" target=\"blank\" ", sep="")
           }
         }
-          
-          
+
+
         ctmp = paste(ctmp, "  />", sep="")
-        
-                
-        
+
+
+
       }# end if header==v2
-      
+
       cat(ctmp,fill=TRUE)
     }
-    
+
     cat("</map>",fill=TRUE)
     cat("<div class=\"plot\">",fill=TRUE)
     if(header=="v1")cat("<img border=\"0\" src=\"",fname.png,"\" usemap=\"img-map\" />",sep="",fill=TRUE)
@@ -1179,11 +1179,11 @@ sendplot <- function(mat, plot.calls, x,y, mai.mat=NA, mai.prc=FALSE,
     cat("</div>",fill=TRUE)
     cat("</body>",fill=TRUE)
     cat("</html>",fill=TRUE)
-    
+
     sink()
 
-  }# end if bound.pt  
-  
+  }# end if bound.pt
+
 }# end sendHeat function
 
 
